/**
 * Main.fx
 *
 * Created on Aug 20, 2009, 9:02:18 PM
 */

package mindfusion.controls.demo;

import javafx.animation.*;
import javafx.scene.*;
import javafx.scene.control.*;
import javafx.scene.effect.*;
import javafx.scene.image.*;
import javafx.scene.layout.*;
import javafx.scene.paint.*;
import javafx.scene.shape.*;
import javafx.scene.text.*;
import javafx.stage.*;

import mindfusion.controls.*;


def margin = 5;
def headerHeight = 50;
def leftPaneWidth = 200;
def descriptionHeight = 60;

var scene: Scene;
var titleLabel: Text;
var contentBack: Rectangle;
var contentPane: Panel;
var descriptionPane: Rectangle;
var descriptionLabel: Text;

var currentStep: Step;
var currentStepContent: Node;

var menuContent: VBox;
var menuOverlay: Group;
var dragX: Number;
var dragY: Number;
var autoScroll: Timeline;
var openSampleRect: Rectangle;


// TODO: Grid view not visible until resize
// TODO: Windows - settings check boxes are not properly bound

def stage:Stage = Stage
{
	title: "MindFusion.Controls for JavaFX Demo";
	icons:
	[
		Image { url: "{__DIR__}Images/IconBig.png"; },
		Image { url: "{__DIR__}Images/IconSmall.png"; },
	];
	width: 800;
	height: 600;

	scene: scene = Scene
	{
        content:
		[
			/* Background */
			Rectangle
			{
				translateX: 0;
				translateY: 0;
				width: bind scene.width;
				height: bind scene.height;
				fill: LinearGradient
				{
					startX: 0;
					startY: 0;
					endX: 1;
					endY: 1;
					stops:
					[
						Stop { offset: 0; color: Color.rgb(0, 0, 0); },
						Stop { offset: 0.2; color: Color.rgb(0, 32, 48); },
						Stop { offset: 0.3; color: Color.rgb(0, 16, 16); },
						Stop { offset: 1; color: Color.rgb(0, 64, 170); },
					]
				};
			},

			/* Frame */
			Rectangle
			{
				translateX: margin;
				translateY: margin;
				width: bind scene.width - 2 * margin;
				height: bind scene.height - 2 * margin;
				arcWidth: 10;
				arcHeight: 10;
				fill: Color.rgb(255, 255, 255, 0.4);
				stroke: Color.rgb(255, 255, 255);
			},

			/* Left pane header background */
			Group
			{
				translateX: margin + 1;
				translateY: margin + 1;
				content:
				[
					Rectangle
					{
						width: leftPaneWidth;
						height: headerHeight;
						clip: Rectangle
						{
							arcWidth: 10;
							arcHeight: 10;
							width: leftPaneWidth + 10;
							height: headerHeight + 10;
						};
						fill: LinearGradient
						{
							startX: 0;
							startY: 0.5;
							endX: 1;
							endY: 0.5;
							stops:
							[
								Stop { offset: 0; color: Color.rgb(48, 96, 170, 0), }
								Stop { offset: 0.6; color: Color.rgb(48, 96, 170, 1) },
							]
						}
					},
					ImageView
					{
						translateX: 18;
						translateY: 3;
						image: Image
						{
							preserveRatio: true;
							url: "{__DIR__}Images/mindfusion-logo.png";
						};
					}
				]
			},

			/* Right pane header background */
			Group
			{
				translateX: margin + leftPaneWidth + 1;
				translateY: margin + 1;
				content:
				[
					Rectangle
					{
						width: bind scene.width - 2 * (margin + 1) - leftPaneWidth;
						height: headerHeight;
						clip: Rectangle
						{
							translateX: -10;
							arcWidth: 10;
							arcHeight: 10;
							width: bind scene.width - 2 * (margin + 1) - leftPaneWidth + 10;
							height: headerHeight + 10;
						};
						fill: LinearGradient
						{
							startX: 0;
							startY: 0.5;
							endX: 1;
							endY: 1;
							stops:
							[
								Stop { offset: 0.6; color: Color.rgb(48, 96, 170, 1) },
								Stop { offset: 1; color: Color.rgb(24, 48, 85, 1), }
							]
						}
					},
					titleLabel = Text
					{
						translateX: 10;
						translateY: 10;
						wrappingWidth: bind scene.width - 2 * (margin + 1) - leftPaneWidth - 10;
						font: Utilities.TitleFontHuge;
						fill: Color.WHITE;
						textOrigin: TextOrigin.TOP;
						effect: DropShadow { };
					}
				]
			},

			/* Header underline */
			Rectangle
			{
				translateX: margin + 1;
				translateY: margin + headerHeight + 1;
				width: bind scene.width - 2 * (margin + 1) + 1;
				height: 1;
				fill: LinearGradient
				{
					startX: 0;
					startY: 0.5;
					endX: 1;
					endY: 0.5;
					stops:
					[
						Stop { offset: 0.05; color: Color.rgb(255, 255, 255, 0); },
						Stop { offset: 0.3; color: Color.rgb(255, 255, 255); },
					];
				};
			},

			/* Panes separator */
			Rectangle
			{
				translateX: margin + leftPaneWidth + 1;
				translateY: margin + 1;
				width: 1;
				height: bind scene.height - 2 * (margin + 1) + 1;
				fill: Color.WHITE;
			},

			/* Menu */
			Group
			{
				translateX: margin;
				translateY: headerHeight + margin + 1;
				content:
				[
					Group
					{
						translateX: margin;
						translateY: margin;
						clip: Rectangle
						{
							width: leftPaneWidth - 2 * (margin - 1);
							height: bind scene.height - headerHeight - 2 * margin - 2 * margin;
						};
						content:
						[
							menuContent = VBox
							{
								translateX: margin;
								translateY: margin;
								spacing: margin + 2;
								content:
								[
									for (stepDesc in Data.Steps)
									{
										def step = Step
										{
											desc: stepDesc;
											imageWidth: 180;
											imageHeight: 102;
											opened: function(step)
											{
												if (currentStep == step)
													return;

												if (currentStep != null)
													currentStep.selected = false;
												step.selected = true;
												currentStep = step;

												def sourceBounds = step.getImageBounds();
												def targetBounds = contentPane.localToScene(contentPane.layoutBounds);

												openSampleRect.translateX = sourceBounds.minX;
												openSampleRect.translateY = sourceBounds.minY;
												openSampleRect.width = sourceBounds.width;
												openSampleRect.height = sourceBounds.height;
												openSampleRect.opacity = 1;

												def _openSampleRect = openSampleRect;

												Timeline
												{
													repeatCount: 1;
													keyFrames:
													[
														KeyFrame
														{
															time: 0.5s;
															values:
															[
																_openSampleRect.translateX => targetBounds.minX tween Interpolator.EASEIN,
																_openSampleRect.translateY => targetBounds.minY tween Interpolator.EASEIN,
																_openSampleRect.width => targetBounds.width tween Interpolator.EASEIN,
																_openSampleRect.height => targetBounds.height tween Interpolator.EASEIN,
																_openSampleRect.opacity => 0 tween Interpolator.EASEIN,
															]
															action: function()
															{
																openStep(step.desc);
															};
														}
													]
												}.play();
											}
										}
										ToolTip.register(step, stepDesc.tooltip);
										step;
									}
								]
							},
						]
					},
					Rectangle
					{
						translateX: 1;
						translateY: 1;
						width: leftPaneWidth;
						height: bind scene.height - headerHeight - 2 * (margin + 1);
						fill: Color.TRANSPARENT;
						blocksMouse: false;
						onMousePressed: function(e)
						{
							dragX = e.x;
							dragY = e.y;
							if (autoScroll != null)
								autoScroll.stop();
						};
						onMouseDragged: function(e)
						{
							if (e.primaryButtonDown)
								menuContent.translateY += e.y - dragY;
							dragY = e.y;
						};
						onMouseReleased: function(e)
						{
							var translation = menuContent.translateY;
							var height = Container.getNodePrefHeight(menuContent);
							var available = scene.height - headerHeight - 2 * (margin + 1) - 2 * margin;
							if (translation < available - height)
								translation = available - height;

							if (translation > 5)
								translation = 5;

							// Using descrete variable here so that the translation is
							// always an integer. This prevents transposition of aligned objects
							var discreteTranslation: Number = menuContent.translateY on replace
							{
								menuContent.translateY = javafx.util.Math.round(discreteTranslation);
							};

							autoScroll = Timeline
							{
								repeatCount: 1;
								keyFrames:
								[
									KeyFrame
									{
										time: 1s;
										values:
										[
											discreteTranslation => translation tween QrtInterpolator { },
										]
									}
								]
							};
							autoScroll.play();
						};
					},
					menuOverlay = Group
					{
						blocksMouse: true;
						content:
						[
							Rectangle
							{
								translateX: 1;
								translateY: 1;
								width: leftPaneWidth;
								height: bind scene.height - headerHeight - 2 * (margin + 1);
								blocksMouse: false;
								fill: Color.BLACK;
								opacity: 0.65;
								onMousePressed: function(e)
								{
									def _menuOverlay = menuOverlay;

									Timeline
									{
										repeatCount: 1;
										keyFrames:
										[
											KeyFrame
											{
												time: 0.4s;
												values:
												[
													_menuOverlay.opacity => 0 tween Interpolator.EASEIN,
												];
												action: function()
												{
													menuOverlay.blocksMouse = false;
												};
											},
										];
									}.play();
								};
							},
							Text
							{
								wrappingWidth: leftPaneWidth - 40;
								translateX: 20;
								translateY: bind (scene.height - headerHeight - 2 * (margin + 1)) / 2 - 20;
								content: "Use mouse dragging to scroll in this menu.\nClick to hide this message.";
								fill: Color.WHITE;
								font: Utilities.TitleFontBig;
								textAlignment: TextAlignment.CENTER;
								effect: DropShadow
								{
									offsetX: 0;
									offsetY: 0;
									width: 30;
									height: 30;
									spread: 0.65;
									color: Color.BLACK;
								};
							}
						];
					},
				];
			},

			contentBack = Rectangle
			{
				translateX: leftPaneWidth + 2 * margin + 1,
				translateY: headerHeight + 2 * margin + 1,
				width: bind scene.width - leftPaneWidth - 2 * margin - 2 * margin - 1;
				height: bind scene.height - headerHeight - 2 * margin - 2 * margin - (descriptionHeight + margin) - 1;
				fill: Color.rgb(0, 0, 0, 0.3);
				stroke: Color.WHITE;
			},

			/* Content panel */
			contentPane = Panel
			{
				translateX: leftPaneWidth + 2 * margin + 1;
				translateY: headerHeight + 2 * margin + 1;
				width: bind scene.width - leftPaneWidth - 2 * margin - 2 * margin - 1;
				height: bind scene.height - headerHeight - 2 * margin - 2 * margin - (descriptionHeight + margin) - 1;
				onLayout: function(): Void
				{
					for (node in contentPane.getManaged(contentPane.content))
						Container.layoutNode(node, 1, 1, contentPane.width - 2, contentPane.height - 2);
				};
			},

			/* Description */
			descriptionPane = Rectangle
			{
				translateX: leftPaneWidth + 2 * margin + 1;
				translateY: bind scene.height - 2 * margin - descriptionHeight;
				width: bind scene.width - leftPaneWidth - 2 * margin - 2 * margin - 1;
				height: descriptionHeight;
				fill: Color.rgb(0, 0, 0, 0.3);
				stroke: Color.WHITE;
			},

			descriptionLabel = Text
			{
				clip: Rectangle
				{
					width: bind descriptionPane.width - 2 * margin;
					height: descriptionHeight - margin - 2;
				};
				translateX: bind descriptionPane.translateX + margin;
				translateY: bind descriptionPane.translateY + margin;
				wrappingWidth: bind descriptionPane.width - 2 * margin;
				fill: Color.WHITE;
				font: Utilities.DefaultFont;
				textOrigin: TextOrigin.TOP;
			},

			openSampleRect = Rectangle
			{
				stroke: Color.WHITE;
				strokeWidth: 1;
				fill: Color.rgb(0, 0, 0, 0.1);
				opacity: 0;
			},

//			Button
//			{
//				text: "DON'T CLICK ME!";
//				action: function()
//				{
//					def c = Controlz
//					{
//						width: bind scene.width;
//						height: bind scene.height;
//					};
//					insert c into scene.content;
//				}
//			}
		]
    }
}

//class Controlz extends Control
//{
//	override var width on replace
//	{
//		(skin as ControlzSkin).root.width = width;
//	};
//
//	override var height on replace
//	{
//		(skin as ControlzSkin).root.height = height;
//	};
//
//	override var skin = ControlzSkin { };
//}
//
//class ControlzSkin extends Skin
//{
//	package var root: Rectangle;
//	init
//	{
//		root = Rectangle
//		{
//			width: control.width;
//			height: control.height;
//			fill: Color.RED;
//			opacity: 0.2;
//		};
//		node = root;
//	}
//
//	override function intersects(x, y, w, h) : Boolean
//	{
//		return node.intersects(x, y, w, h);
//	}
//
//	override function contains(x, y) : Boolean
//	{
//		return node.contains(x, y);
//	}
//}

/**
 * Opens the step with the specified descriptor within the current scene.
 */
function openStep(stepDesc: Step.Desc): Void
{
	if (currentStepContent != null)
		delete currentStepContent from contentPane.content;

	titleLabel.content = stepDesc.title;
	descriptionLabel.content = stepDesc.description;
	if (stepDesc.id == Data.STEP_INTRODUCTION)
	{
		currentStepContent = StepIntroduction
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
			navigate: function (stepDesc)
			{
				openStep(stepDesc);
			};
		};
	}
	else if (stepDesc.id == Data.STEP_WINDOW)
	{
		currentStepContent = StepWindow
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_GRID)
	{
		currentStepContent = StepGrid
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_LISTVIEW)
	{
		currentStepContent = StepListView
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_TREEVIEW)
	{
		currentStepContent = StepTreeView
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_TABVIEW)
	{
		currentStepContent = StepTabView
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_MENU)
	{
		currentStepContent = StepMenu
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_TOOLBAR)
	{
		currentStepContent = StepToolBar
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_TOOLTIP)
	{
		currentStepContent = StepToolTip
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_DROPDOWN)
	{
		currentStepContent = StepDropDown
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_CALENDAR)
	{
		currentStepContent = StepCalendar
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	else if (stepDesc.id == Data.STEP_CLOCK)
	{
		currentStepContent = StepClock
		{
			width: bind contentPane.width;
			height: bind contentPane.height;
		};
	}
	insert currentStepContent into contentPane.content;
}

// Open the introduction step
openStep(
	Step.Desc
	{
		id: Data.STEP_INTRODUCTION;
		title: "Welcome!";
		description: "";
	});
