/*
 * Step.fx
 *
 * Created on Feb 25, 2010, 1:02:37 PM
 */

package mindfusion.controls.demo;

import javafx.animation.*;
import javafx.geometry.*;
import javafx.scene.control.*;
import javafx.scene.image.*;
import javafx.scene.input.*;
import javafx.scene.layout.*;
import javafx.scene.paint.*;
import javafx.scene.shape.*;
import javafx.scene.effect.*;
import javafx.util.*;


/**
 * @author Meppy
 */

package class Step extends Control
{
	public var desc: Desc;

	public var imageWidth: Number;
	public var imageHeight: Number;
	public var selected: Boolean;

	public var opened: function(step: Step);

	/**
	 * Returns the bounds of the image part of this step, in screen coordinates.
	 */
	public function getImageBounds(): Bounds
	{
		(skin as StepSkin).getImageBounds();
	}

	override var skin = StepSkin { };

	override function getPrefWidth(height: Number)
	{
		return Container.getNodePrefWidth(skin.node);
	}

	override function getPrefHeight(width: Number)
	{
		return Container.getNodePrefHeight(skin.node);
	}
}

class StepSkin extends Skin
{
	var imageRect: Rectangle;

	init
	{
		var a = 0.0;
		var r = 255;
		var g = 255;
		var b = 0;
		var panel: Panel;

		def content: VBox = VBox
		{
			spacing: 0;
			effect: DropShadow
			{
				color: bind Color.rgb(r, g, b, a);
			};
			onMouseReleased: function(e)
			{
				if (e.button == MouseButton.PRIMARY)
				{
					if (Math.abs(e.dragX) < 5 and Math.abs(e.dragY) < 5)
						opened(control as Step);
				}
			};
			onMouseEntered: function(e)
			{
				// Fade in shadow
				Timeline
				{
					repeatCount: 1
					keyFrames:
					[
						KeyFrame {
							time: .2s
							values:
							[
								a => 1.0 tween Interpolator.EASEIN,
							]
						}
					]
				}.play();
			};
			onMouseExited: function(e)
			{
				// Fade out shadow
				Timeline
				{
					repeatCount: 1
					keyFrames:
					[
						KeyFrame {
							time: .2s
							values:
							[
								a => 0.0 tween Interpolator.EASEIN,
							]
						}
					]
				}.play();
			};
			content:
			[
				Panel
				{
					content:
					[
						imageRect = Rectangle
						{
							fill: bind if (selected) Color.rgb(255, 255, 0, 0.25) else Color.rgb(0, 0, 0, 0.5);
							//stroke: bind if (selected) Color.WHITE else Color.LIGHTSTEELBLUE;
							width: bind imageWidth;
							height: bind imageHeight;
						},
						ImageView
						{
							translateX: 1;
							translateY: 1;
							image: bind desc.image;
							// Lazy positioning - assuming all images are properly sized
							x: bind imageWidth / 2 - 1 - desc.image.width / 2;
							y: bind imageHeight / 2 - 1 - desc.image.height / 2;
							fitWidth: bind imageWidth - 1;
							fitHeight: bind imageHeight - 1;
							preserveRatio: true;
							smooth: false;
						},
					]
				},
				panel = Panel
				{
					width: bind imageWidth;
					height: 25;
					content:
					[
						Rectangle
						{
							width: bind imageWidth;
							height: 25;
							fill: RadialGradient
							{
								centerX: 0.5;
								centerY: 0;
								proportional: true;
								stops:
								[
									Stop { offset: 0; color: Color.rgb(0, 0, 0, 0.5); },
									Stop { offset: 0.5; color: Color.rgb(0, 0, 0, 0); },
								];
							};
						},
						Label
						{
							text: bind desc.title;
							hpos: HPos.CENTER;
							effect: DropShadow { };
							blocksMouse: true;
							font: Utilities.DefaultTitleFont;
							textFill: Color.WHITE;
						},
					];
					onLayout: function()
					{
						panel.resizeContent();
						for (node in panel.getManaged(panel.content))
						{
							def x = Container.getNodePrefWidth(panel) / 2 - Container.getNodePrefWidth(node) / 2;
							def y = Container.getNodePrefHeight(panel) / 2 - Container.getNodePrefHeight(node) / 2;
							Container.positionNode(node, x, y);
						}
					};
				},
			];
		};

		node = content;
	}

	public function getImageBounds(): Bounds
	{
		imageRect.localToScene(imageRect.boundsInLocal);
	}

	override function intersects(x, y, w, h) : Boolean
	{
		return node.intersects(x, y, w, h);
	}

	override function contains(x, y) : Boolean
	{
		return node.contains(x, y);
	}
}


package class Desc
{
	public var id: Integer;
	public var image: Image;
	public var title: String;
	public var tooltip: String;
	public var description: String;
}