/*
 * StepIntroduction.fx
 *
 * Created on Feb 26, 2010, 11:29:32 AM
 */

package mindfusion.controls.demo;

import javafx.scene.*;
import javafx.scene.control.*;
import javafx.scene.layout.*;
import javafx.scene.paint.*;
import javafx.scene.shape.*;
import javafx.scene.text.*;
import javafx.geometry.*;

import mindfusion.controls.*;


/**
 * @author Meppy
 */

class TitleLink extends CustomNode
{
	public var text: String;
	public var click: function();

	public var fill: Paint = Color.rgb(235, 222, 155);
	public var hoverFill: Paint = Color.rgb(255, 245, 198);
	public var font: Font = Utilities.DefaultTitleFont;

	override function create(): Node
	{
		var titleBack: Rectangle;
		var title: Label;

		Group
		{
			content:
			[
				titleBack = Rectangle
				{
					width: bind title.boundsInLocal.width;
					height: bind title.boundsInLocal.height + 2;
					cursor: Cursor.HAND;
					fill: Color.TRANSPARENT;
					onMouseClicked: function(e)
					{
						click();
					};
				},
				title = Label
				{
					text: bind text;
					textFill: bind if (titleBack.hover) hoverFill else fill;
					font: bind font;
				},
			]
		}
	}
}


package class StepIntroduction extends StepBase
{
	public var navigate: function(step: Step.Desc);

	override function create(): Node
	{
		def margin = 5;

		mindfusion.controls.ScrollView
		{
			translateX: 1;
			translateY: 1;
			width: bind width - 2;
			height: bind height - 2;
			hscrollBarVisible: false;
			content: VBox
			{
				translateX: margin;
				translateY: margin;
				spacing: 2;
				content:
				[
					Text
					{
						content: "Welcome to the MindFusion.Controls for JavaFX demonstration program. "
							"The program features several steps, which introduce the individual controls "
							"contained in this package. The steps can be accessed from the pane to the left. "
							"To scroll the pane up and down, click anywhere in the pane with the mouse and drag. "
							"To access a step, click on its image with the mouse. When a step is opened, a short "
							"description illustrating the most important aspects of the step can be found "
							"at the bottom of this window. Have fun!";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "Grid";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_GRID));
						};
					},
					Text
					{
						content: "The Grid control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "ListView";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_LISTVIEW));
						};
					},
					Text
					{
						content: "The ListView control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "TreeView";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_TREEVIEW));
						};
					},
					Text
					{
						content: "The TreeView control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "TabView";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_TABVIEW));
						};
					},
					Text
					{
						content: "The TabView control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "Window";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_WINDOW));
						};
					},
					Text
					{
						content: "The Window control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "Menu";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_MENU));
						};
					},
					Text
					{
						content: "The Menu control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "ToolBar";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_TOOLBAR));
						};
					},
					Text
					{
						content: "The ToolBar control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "ToolTip";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_TOOLTIP));
						};
					},
					Text
					{
						content: "The ToolTip control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "DropDown";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_DROPDOWN));
						};
					},
					Text
					{
						content: "The ComboBox control.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "Calendar";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_CALENDAR));
						};
					},
					Text
					{
						content: "A control representing a single month calendar.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					TitleLink
					{
						text: "Clock";
						click: function()
						{
							navigate(Data.getStep(Data.STEP_CLOCK));
						};
					},
					Text
					{
						content: "A control representing an analog clock. The control currently "
							"provides limited customizability options.";
						wrappingWidth: bind width - 5 * margin;
						fill: Color.WHITE;
						font: Utilities.DefaultFont;
					},
					Rectangle
					{
						translateY: 10;
						translateX: margin;
						width: bind width - 6 * margin;
						height: 2;
						fill: Color.WHITE;
					}
					Flow
					{
						translateY: 20;
						nodeVPos: VPos.TOP;
						vertical: false;
						width: bind width - 5 * margin;
						content:
						[
							Text
							{
								content: "For more information, visit our site ";
								fill: Color.WHITE;
								font: Utilities.DefaultFont;
							},
							Text
							{
								content: "http://mindfusion.eu/";
								fill: Color.LIGHTBLUE;
								font: Utilities.DefaultFont;
								underline: true;
							},
							Text
							{
								content: "or contact us via e-mail at ";
								fill: Color.WHITE;
								font: Utilities.DefaultFont;
							},
							Text
							{
								content: "support@mindfusion.eu";
								fill: Color.LIGHTBLUE;
								font: Utilities.DefaultFont;
								underline: true;
							},
							Text
							{
								content: "!";
								fill: Color.WHITE;
								font: Utilities.DefaultFont;
							}
						]
					}
				]
			}
		};
	}
}
