/*
 * StepToolTip.fx
 *
 * Created on Feb 26, 2010, 10:23:28 AM
 */

package mindfusion.controls.demo;

import javafx.geometry.*;
import javafx.scene.*;
import javafx.scene.layout.*;
import javafx.scene.control.*;
import javafx.scene.image.*;
import javafx.scene.paint.*;
import javafx.scene.text.*;
import javafx.scene.shape.*;

import mindfusion.controls.*;


/**
 * @author Meppy
 */

package class StepToolTip extends StepBase
{
	override function create(): Node
	{
		var button1: Button;
		var button2: Button;
		var treeView: TreeView;
		var listView: mindfusion.controls.ListView;
		var labelGroup: Group;
		var label: Label;

		def margin = 5;

		def root = Group
		{
			translateX: 2 * margin;
			translateY: 2 * margin;
			content:
			[
				VBox
				{
					spacing: margin;
					content:
					[
						button1 = Button
						{
							width: 100;
							height: 80;
							text: "I am a button with a simple string tooltip.";
							font: Utilities.DefaultFont;
						},
						button2 = Button
						{
							text: "I am a button with a more complicated tooltip.";
							font: Utilities.DefaultFont;
						},
						Label
						{
							text: "The TreeView and ListView below provide specific tooltips for individual items.";
							textFill: Color.WHITE;
							font: Utilities.DefaultFont;
						},
						HBox
						{
							spacing: margin;
							content:
							[
								treeView = TreeView
								{
									width: 160;
									height: 200;
									items:
									[
										for (i in [1..10])
											TreeViewItem
											{
												content: Label
												{
													text: "Item #{i}";
													font: Utilities.DefaultFont;
												}
											}
									]
								},
								listView = mindfusion.controls.ListView
								{
									width: 160;
									height: 200;
									items: for (i in [1..10])
										ListViewItem { text: "Item #{i}" };
								}
							]
						},
						labelGroup = Group
						{
							content:
							[
								Rectangle
								{
									width: bind label.layoutBounds.width + 8;
									height: bind label.layoutBounds.height + 8;
									fill: Color.rgb(0, 0, 0, 0.25);
								}
								label = Label
								{
									translateX: 4;
									translateY: 4;
									text: "I am a label with a very fancy tooltip.";
									textFill: Color.WHITE;
									font: Utilities.DefaultTitleFont;
								}
							]
						}
					]
				}
			]
		}

		ToolTip.register(button1, "A simple string tooltip.");
		ToolTip.register(button2,
			HBox
			{
				nodeVPos: VPos.CENTER;
				spacing: 5;
				content:
				[
					ImageView
					{
						image: Image
						{
							url: "{__DIR__}Images/03.png";
							width: 32;
							height: 32;
						}
					},
					VBox
					{
						content:
						[
							Label
							{
								text: "A more complex tooltip";
								font: Utilities.DefaultTitleFont;
							},
							Label
							{
								text: "This tooltip contains an image and a header text.";
								font: Utilities.DefaultFont;
							}
						]
					}
				]
			});
		for (item in treeView.items)
			ToolTip.register(item, "This is tooltip for {(item.content as Label).text}.");
		for (item in listView.items)
			ToolTip.register(item, "This is tooltip for {item}.");

		ToolTip.register(labelGroup, Clock { width: 120; height: 120; });

		root;
	}
}

public class ListViewItem extends CustomNode
{
	public var text: String;

	override function toString()
	{
		return text;
	}

	override function create(): Node
	{
		def label = Label
		{
			text: bind text;
		};
		def background = Rectangle
		{
			width: bind label.boundsInLocal.width;
			height: bind label.boundsInLocal.height;
			fill: Color.TRANSPARENT;
		};

		Panel
		{
			content:
			[
				background,
				label,
			];
		};
	}
}
