/*
 * StepTreeView.fx
 *
 * Created on Mar 1, 2010, 10:10:32 AM
 */

package mindfusion.controls.demo;

import javafx.scene.*;
import javafx.scene.control.*;
import javafx.scene.layout.*;
import javafx.scene.paint.*;
import javafx.scene.text.*;
import javafx.geometry.*;
import javafx.util.*;

import mindfusion.controls.*;


/**
 * @author Meppy
 */

package class StepTreeView extends StepBase
{
	override function create(): Node
	{
		def margin = 5;

		var label1: Label;
		var label2: Label;
		var checkBox1: CheckBox;
		var checkBox2: CheckBox;

		def toggleGroup1 = ToggleGroup { };
		var checkBox3: CheckBox;
		var scrollBar: ScrollBar;

		HBox
		{
			translateX: 2 * margin;
			translateY: 2 * margin;
			spacing: 4 * margin;
			content:
			[
				VBox
				{
					spacing: margin;
					content:
					[
						Label
						{
							text: "Ordinary tree view:";
							textFill: Color.WHITE;
							font: Utilities.DefaultFont;
						},
						TreeView
						{
							width: 200;
							height: 240;
							showExpandCollapse: bind if (checkBox1 != null) checkBox1.selected else true;
							showLines: bind if (checkBox2 != null) checkBox2.selected else true;
							items:
							[
								Utilities.createTreeViewItem("Manager #1", "012.png", false,
									[
										Utilities.createTreeViewItem("Team Leader #1", "019.png", false,
										[
											Utilities.createTreeViewItem("Developer #1", "057.png"),
											Utilities.createTreeViewItem("Developer #2", "020.png"),
										]),
										Utilities.createTreeViewItem("Team Leader #2", "026.png", false,
										[
											Utilities.createTreeViewItem("Developer #3", "057.png"),
											Utilities.createTreeViewItem("Developer #4", "020.png"),
											Utilities.createTreeViewItem("Developer #5", "020.png"),
										]),
									]),
								Utilities.createTreeViewItem("Manager #2", "026.png", false,
									[
										Utilities.createTreeViewItem("Team Leader #3", "026.png", false,
										[
											Utilities.createTreeViewItem("Developer #6", "026.png"),
											Utilities.createTreeViewItem("Developer #7", "012.png"),
										]),
										Utilities.createTreeViewItem("Team Leader #4", "026.png"),
										Utilities.createTreeViewItem("Team Leader #5", "026.png", false,
										[
											Utilities.createTreeViewItem("Developer #8", "020.png"),
										]),
									]),
							]
						},
						Group
						{
							content:
							[
								checkBox1 = CheckBox
								{
									selected: true;
									width: bind 18 + label1.boundsInLocal.width;
								},
								label1 = Label
								{
									translateX: 18;
									translateY: 2;
									text: "Show Expand/Collapse Buttons";
									textFill: Color.WHITE;
									font: Utilities.DefaultFont;
								}
							]
						},
						Group
						{
							content:
							[
								checkBox2 = CheckBox
								{
									selected: true;
									width: bind 18 + label2.boundsInLocal.width;
								}
								label2 = Label
								{
									translateX: 18;
									translateY: 2;
									text: "Show Lines";
									textFill: Color.WHITE;
									font: Utilities.DefaultFont;
								}
							]
						}
					],
				},
				VBox
				{
					spacing: margin;
					content:
					[
						Label
						{
							text: "Advanced tree view:";
							textFill: Color.WHITE;
							font: Utilities.DefaultFont;
						}
						TreeView
						{
							width: 320;
							height: 240;
							items:
							[
								Utilities.createTreeViewItem("Browsing", "068.png", false,
								[
									TreeViewItem
									{
										content: CheckBox
										{
											text: "Notify when downloads complete";
											selected: true;
										}
									},
									TreeViewItem
									{
										content: HBox
										{
											spacing: 4;
											nodeVPos: VPos.CENTER;
											content:
											[
												checkBox3 = CheckBox
												{
													text: "Disable script debugging";
													selected: true;
												},
												Button
												{
													text: "Settings...";
													disable: bind not checkBox3.selected;
													action: function()
													{
														MessageBox.show(scene, "Script Debugging Settings", "MindFusion.Controls for JavaFX");
													};
												},
											];
										};
									},
									Utilities.createTreeViewItem("Underline links", "068.png", false,
									[
										TreeViewItem
										{
											content: RadioButton
											{
												text: "Always";
												selected: true;
												toggleGroup: toggleGroup1;
											};
										},
										TreeViewItem
										{
											content: RadioButton
											{
												text: "Hover";
												selected: false;
												toggleGroup: toggleGroup1;
											};
										},
										TreeViewItem
										{
											content: RadioButton
											{
												text: "Never";
												selected: false;
												toggleGroup: toggleGroup1;
											};
										},
									]),
								]),
								Utilities.createTreeViewItem("Security", "068.png", false,
								[
									TreeViewItem
									{
										content: HBox
										{
											translateX: 5;
											translateY: 5;
											spacing: 4;
											layoutInfo: LayoutInfo
											{
												height: 70;
												width: 200;
											};
											content:
											[
												scrollBar = ScrollBar
												{
													vertical: true;
													min: 0;
													max: 2;
													layoutInfo: LayoutInfo
													{
														height: 60;
													};
													impl_onValueChanged: function(oldValue, newValue)
													{
														// Descrete value change - no idea if this is the proper way
														scrollBar.value = Math.round(newValue);
													}
												},
												VBox
												{
													spacing: 4;
													content: bind if (scrollBar.value == 0)
														[
															Label
															{
																text: "High";
																font: Utilities.DefaultTitleFont;
															},
															Text
															{
																content: "Appropriate for websites that might have harmful content";
																wrappingWidth: 170;
																font: Utilities.DefaultFont;
															},
														]
														else if (scrollBar.value == 1)
														[
															Label
															{
																text: "Medium";
																font: Utilities.DefaultTitleFont;
															},
															Text
															{
																content: "Prompts before downloading potentially unsafe content";
																wrappingWidth: 170;
																font: Utilities.DefaultFont;
															},
														]
														else
														[
															Label
															{
																text: "Low";
																font: Utilities.DefaultTitleFont;
															},
															Text
															{
																content: "Appropriate for sites that you absolutely trust";
																wrappingWidth: 170;
																font: Utilities.DefaultFont;
															},
														];
												},
											];
										};
									},
								]),
								Utilities.createTreeViewItem("Multimedia", "068.png", false,
								[
									TreeViewItem
									{
										content: CheckBox
										{
											text: "Play animations in web pages";
											selected: true;
										}
									},
									TreeViewItem
									{
										content: CheckBox
										{
											text: "Play sounds in web pages";
											selected: false;
										}
									},
									TreeViewItem
									{
										content: CheckBox
										{
											text: "Show pictures";
											selected: true;
										}
									},
								]),
							];
						}
					]
				}
			]
		};
	}
}
