/*
 * StepWindow.fx
 *
 * Created on Feb 25, 2010, 3:38:33 PM
 */

package mindfusion.controls.demo;

import javafx.scene.*;
import javafx.scene.control.*;
import javafx.scene.image.*;
import javafx.scene.input.*;
import javafx.scene.layout.*;
import javafx.scene.paint.*;

import mindfusion.controls.*;


/**
 * @author Meppy
 */

package class StepWindow extends StepBase
{
	var checkBox1: CheckBox;
	var checkBox2: CheckBox;
	var checkBox3: CheckBox;
	var checkBox4: CheckBox;
	var window: Window;
	def checkBox1Value = bind checkBox1.selected on replace
	{
		window.canMinimize = checkBox1Value;
	};
	def checkBox2Value = bind checkBox2.selected on replace
	{
		window.canMaximize = checkBox2Value;
	};
	def checkBox3Value = bind checkBox3.selected on replace
	{
		window.canClose = checkBox3Value;
	};
	def checkBox4Value = bind checkBox4.selected on replace
	{
		window.sizable = checkBox4Value;
	};

	override function create(): Node
	{
		def margin = 1;

		checkBox1 = CheckBox
		{
			text: "Can Minimize";
			font: Utilities.DefaultFont;
			selected: true;
		};
		checkBox2 = CheckBox
		{
			text: "Can Maximize";
			font: Utilities.DefaultFont;
			selected: true;
		};
		checkBox3 = CheckBox
		{
			text: "Can Close";
			font: Utilities.DefaultFont;
			selected: true;
		};
		checkBox4 = CheckBox
		{
			text: "Can Resize";
			font: Utilities.DefaultFont;
			selected: true;
		};

		def host: WindowHost = WindowHost
		{
			translateX: margin;
			translateY: margin;
			width: bind this.width - 2 * margin;
			height: bind this.height - 2 * margin;
			fill: Color.rgb(0, 0, 0, 0.25);
			windows:
			[
				window = Window
				{
					title: "Sample Window";
					translateX: 50;
					translateY: 50;
					width: 400;
					height: 300;
					icon: Image { url: "{__DIR__}Images/068.png" };
					content: VBox
					{
						content:
						[
							checkBox1,
							checkBox2,
							checkBox3,
							checkBox4,
						];
					};
					canMinimize: true;
					canMaximize: true;
					canClose: true;
					sizable: true;
				}
			];
			onMouseClicked: function(e)
			{
				if (e.button == MouseButton.SECONDARY)
				{
					menu.show(host, e.x, e.y);
				}
			}
		};

		def menu = ContextMenu
		{
			items:
			[
				MenuItem
				{
					node: Label
					{
						text: "Create New Window";
						font: Utilities.DefaultFont;
					};
					action: function(source: MenuItem)
					{
						Window
						{
							translateX: (sizeof host.windows) * 20;
							translateY: (sizeof host.windows) * 20;
							width: 200;
							height: 120;
						}.openIn(host);
					}
				},
				MenuItem
				{
					node: Label
					{
						text: "Create New MDI Window";
						font: Utilities.DefaultFont;
					};
					action: function(source: MenuItem)
					{
						MyMdiWindow
						{
							title: "MDI Window";
							translateX: (sizeof host.windows) * 20;
							translateY: (sizeof host.windows) * 20;
							width: 400;
							height: 300;
						}.openIn(host);
					}
				},
				MenuItem
				{
					node: Label
					{
						text: "Minimize All Windows";
						font: Utilities.DefaultFont;
					};
					action: function(source: MenuItem)
					{
						for (w in host.windows)
						{
							if (w.state != WindowState.MINIMIZED)
								w.toggleMinimize();
						}
					};
				},
			];
		};

		Group
		{
			content:
			[
				host,
				menu,
			];
		};
	}
}

class MyMdiWindow extends MdiWindow
{
	init
	{
		width = 300;
		height = 200;
		title = "MDI Host";

		def menuItemNew = MenuItem
		{
			node: Label
			{
				text: "New";
			};
			items: bind
			[
				MenuItem
				{
					node: Label
					{
						text: "Simple Window";
					};
					action: function(source: MenuItem)
					{
						addMdiChild(Window
						{
							title: "MDI Child";
							width: 200;
							height: 120;
						});
					}
				},
				MenuItem
				{
					node: Label
					{
						text: "MDI Window";
					};
					action: function(e)
					{
						addMdiChild(MyMdiWindow { });
					};
				}
			]
		};

		insert menuItemNew before menu.items[0];
	}
}